@@ -1,6 +1,6 @@
 package Bitcoin::Crypto::Exception;
 
-our $VERSION = "0.996";
+our $VERSION = "0.997";
 
 use v5.10;
 use warnings;
@@ -98,13 +98,6 @@ sub as_string
 
 }
 
-{
-
-	# old form - deprecated
-	package Bitcoin::Crypto::Exception::KeySign;
-	use parent -norequire, "Bitcoin::Crypto::Exception::Sign";
-}
-
 {
 
 	package Bitcoin::Crypto::Exception::Verify;
